==> ansible-3.3.0-2-any.pkg.tar.zst: usr/lib/python3.9/site-packages/ansible_collections/inspur/sm/plugins/modules/edit_restore_factory_default.py <==
#!/usr/bin/python
# -*- coding:utf-8 -*-

# Copyright(C) 2020 Inspur Inc. All Rights Reserved.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import (absolute_import, division, print_function)

__metaclass__ = type

DOCUMENTATION = '''
---
module: edit_restore_factory_default
version_added: "0.1.0"
author:
    - WangBaoshan (@ISIB-group)
short_description: Set preserver config.
description:
   - Set preserver config on Inspur server.
options:
    mode:
        description:
            - Restore factory defaults mode.
        choices: ['auto', 'manual']
        type: str
        required: true
    override:
        description:
            - Configuration items that need to be retained.
            - Required when I(mode=manual).
        choices: ['authentication', 'dcmi', 'fru', 'hostname', 'ipmi', 'kvm', 'network', 'ntp', 'pef',
         'sdr', 'sel', 'smtp', 'snmp', 'sol', 'ssh', 'syslog', 'user']
        type: list
        elements: str
extends_documentation_fragment:
    - inspur.sm.ism
'''

EXAMPLES = '''
- name: Restore default test
  hosts: ism
  connection: local
  gather_facts: no
  vars:
    ism:
      host: "{{ ansible_ssh_host }}"
      username: "{{ username }}"
      password: "{{ password }}"

  tasks:

  - name: "Set restore default auto"
    inspur.sm.edit_restore_factory_default:
      mode: "all"
      provider: "{{ ism }}"

  - name: "Set restore default manual"
    inspur.sm.edit_restore_factory_default:
      mode: "manual"
      override:
        - fru
        - ntp
        - network
        - user
      provider: "{{ ism }}"
'''

RETURN = '''
message:
    description: Messages returned after module execution.
    returned: always
    type: str
state:
    description: Status after module execution.
    returned: always
    type: str
changed:
    description: Check to see if a change was made on the device.
    returned: always
    type: bool
'''

from ansible.module_utils.basic import AnsibleModule
from ansible_collections.inspur.sm.plugins.module_utils.ism import (ism_argument_spec, get_connection)


class Preserver(object):
    def __init__(self, argument_spec):
        self.spec = argument_spec
        self.module = None
        self.init_module()
        self.results = dict()

    def init_module(self):
        """Init module object"""

        self.module = AnsibleModule(
            argument_spec=self.spec, supports_check_mode=False)

    def run_command(self):
        self.module.params['subcommand'] = 'restorefactorydefaults'
        self.results = get_connection(self.module)
        if self.results['State'] == 'Success':
            self.results['changed'] = True

    def show_result(self):
        """Show result"""
        self.module.exit_json(**self.results)

    def work(self):
        """Worker"""
        self.run_command()
        self.show_result()


def main():
    argument_spec = dict(
        mode=dict(type='str', required=True, choices=['auto', 'manual']),
        override=dict(type='list', elements='str', required=False,
                      choices=['authentication', 'dcmi', 'fru', 'hostname', 'ipmi', 'kvm', 'network', 'ntp',
                               'pef', 'sdr', 'sel', 'smtp', 'snmp', 'sol', 'ssh', 'syslog', 'user']),
    )
    argument_spec.update(ism_argument_spec)
    pre_obj = Preserver(argument_spec)
    pre_obj.work()


if __name__ == '__main__':
    main()

==> ansible-9.1.0-2-any.pkg.tar.zst: usr/lib/python3.12/site-packages/ansible_collections/inspur/sm/plugins/modules/edit_restore_factory_default.py <==
#!/usr/bin/python
# -*- coding:utf-8 -*-

# Copyright(C) 2020 Inspur Inc. All Rights Reserved.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import (absolute_import, division, print_function)

__metaclass__ = type

DOCUMENTATION = '''
---
module: edit_restore_factory_default
version_added: "0.1.0"
author:
    - WangBaoshan (@ISIB-group)
short_description: Set preserver config.
description:
   - Set preserver config on Inspur server.
options:
    mode:
        description:
            - Restore factory defaults mode.
        choices: ['all', 'none', 'manual']
        type: str
        required: true
    override:
        description:
            - Configuration items that need to be retained.
            - Required when I(mode=manual).
        choices: ['authentication', 'dcmi', 'fru', 'hostname', 'ipmi', 'kvm', 'network', 'ntp', 'pef',
         'sdr', 'sel', 'smtp', 'snmp', 'sol', 'ssh', 'syslog', 'user']
        type: list
        elements: str
extends_documentation_fragment:
    - inspur.sm.ism
'''

EXAMPLES = '''
- name: Restore default test
  hosts: ism
  connection: local
  gather_facts: no
  vars:
    ism:
      host: "{{ ansible_ssh_host }}"
      username: "{{ username }}"
      password: "{{ password }}"

  tasks:

  - name: "Set restore default auto"
    inspur.sm.edit_restore_factory_default:
      mode: "all"
      provider: "{{ ism }}"

  - name: "Set restore default manual"
    inspur.sm.edit_restore_factory_default:
      mode: "manual"
      override:
        - fru
        - ntp
        - network
        - user
      provider: "{{ ism }}"
'''

RETURN = '''
message:
    description: Messages returned after module execution.
    returned: always
    type: str
state:
    description: Status after module execution.
    returned: always
    type: str
changed:
    description: Check to see if a change was made on the device.
    returned: always
    type: bool
'''

from ansible.module_utils.basic import AnsibleModule
from ansible_collections.inspur.sm.plugins.module_utils.ism import (ism_argument_spec, get_connection)


class Preserver(object):
    def __init__(self, argument_spec):
        self.spec = argument_spec
        self.module = None
        self.init_module()
        self.results = dict()

    def init_module(self):
        """Init module object"""

        self.module = AnsibleModule(
            argument_spec=self.spec, supports_check_mode=False)

    def run_command(self):
        self.module.params['subcommand'] = 'restorefactorydefaults'
        self.results = get_connection(self.module)
        if self.results['State'] == 'Success':
            self.results['changed'] = True

    def show_result(self):
        """Show result"""
        self.module.exit_json(**self.results)

    def work(self):
        """Worker"""
        self.run_command()
        self.show_result()


def main():
    argument_spec = dict(
        mode=dict(type='str', required=True, choices=['all', 'none', 'manual']),
        override=dict(type='list', elements='str', required=False,
                      choices=['authentication', 'dcmi', 'fru', 'hostname', 'ipmi', 'kvm', 'network', 'ntp',
                               'pef', 'sdr', 'sel', 'smtp', 'snmp', 'sol', 'ssh', 'syslog', 'user']),
    )
    argument_spec.update(ism_argument_spec)
    pre_obj = Preserver(argument_spec)
    pre_obj.work()


if __name__ == '__main__':
    main()
